# ODSL Python SDK

__title__ = "odsl"
__description__ = "ODSL Python SDK."
__url__ = "https://doc.opendatadsl.com"
__version__ = "1.0.0"
__build__ = 0x023100
__author__ = "Colin Hartley"
__author_email__ = "colin.hartley@opendatadsl.com"
__license__ = "Apache-2.0"
__copyright__ = "Copyright OpenDataDSL Ltd."
__cake__ = "\u2728 \U0001f370 \u2728"